@@ -7,14 +7,29 @@ Extended thread dispatching support.
 For basic support see reactor threading API docs.
 """
 
+from __future__ import annotations
 
 import queue as Queue
+from typing import Callable, TypeVar
+
+from typing_extensions import ParamSpec
 
 from twisted.internet import defer
+from twisted.internet.interfaces import IReactorFromThreads
 from twisted.python import failure
+from twisted.python.threadpool import ThreadPool
+
+_P = ParamSpec("_P")
+_R = TypeVar("_R")
 
 
-def deferToThreadPool(reactor, threadpool, f, *args, **kwargs):
+def deferToThreadPool(
+    reactor: IReactorFromThreads,
+    threadpool: ThreadPool,
+    f: Callable[_P, _R],
+    *args: _P.args,
+    **kwargs: _P.kwargs,
+) -> defer.Deferred[_R]:
     """
     Call the function C{f} using a thread from the given threadpool and return
     the result as a Deferred.
@@ -37,9 +52,9 @@ def deferToThreadPool(reactor, threadpool, f, *args, **kwargs):
         errback with a L{twisted.python.failure.Failure} if f throws an
         exception.
     """
-    d = defer.Deferred()
+    d: defer.Deferred[_R] = defer.Deferred()
 
-    def onResult(success, result):
+    def onResult(success: bool, result: _R | BaseException) -> None:
         if success:
             reactor.callFromThread(d.callback, result)
         else:
