@@ -13,14 +13,12 @@ Support for aliases(5) configuration files.
 import os
 import tempfile
 
+from zope.interface import implementer
+
+from twisted.internet import defer, protocol, reactor
 from twisted.mail import smtp
 from twisted.mail.interfaces import IAlias
-from twisted.internet import reactor
-from twisted.internet import protocol
-from twisted.internet import defer
-from twisted.python import failure
-from twisted.python import log
-from zope.interface import implementer
+from twisted.python import failure, log
 
 
 def handle(result, line, filename, lineNo):
@@ -117,7 +115,7 @@ def loadAliasFile(domains, filename=None, fp=None):
             fp.close()
     if prev:
         handle(result, prev, filename, i)
-    for (u, a) in result.items():
+    for u, a in result.items():
         result[u] = AliasGroup(a, domains, u)
     return result
 
@@ -205,7 +203,7 @@ class AddressAlias(AliasBase):
         @rtype: L{bytes}
         @return: A string containing the destination address.
         """
-        return "<Address {}>".format(self.alias)
+        return f"<Address {self.alias}>"
 
     def createMessageReceiver(self):
         """
@@ -314,7 +312,7 @@ class FileWrapper:
         @rtype: L{bytes}
         @return: A string containing the file name of the message.
         """
-        return "<FileWrapper {}>".format(self.finalname)
+        return f"<FileWrapper {self.finalname}>"
 
 
 @implementer(IAlias)
@@ -344,7 +342,7 @@ class FileAlias(AliasBase):
         @rtype: L{bytes}
         @return: A string containing the name of the file.
         """
-        return "<File {}>".format(self.filename)
+        return f"<File {self.filename}>"
 
     def createMessageReceiver(self):
         """
@@ -480,9 +478,7 @@ class MessageWrapper:
         """
         self._timeoutCallID = None
         self.protocol.transport.signalProcess("KILL")
-        exc = ProcessAliasTimeout(
-            "No answer after {} seconds".format(self.completionTimeout)
-        )
+        exc = ProcessAliasTimeout(f"No answer after {self.completionTimeout} seconds")
         self.protocol.onEnd = None
         self.completion.errback(failure.Failure(exc))
 
@@ -498,7 +494,7 @@ class MessageWrapper:
         @rtype: L{bytes}
         @return: A string containing the name of the process.
         """
-        return "<ProcessWrapper {}>".format(self.processName)
+        return f"<ProcessWrapper {self.processName}>"
 
 
 class ProcessAliasProtocol(protocol.ProcessProtocol):
@@ -566,7 +562,7 @@ class ProcessAlias(AliasBase):
         @rtype: L{bytes}
         @return: A string containing the command used to invoke the process.
         """
-        return "<Process {}>".format(self.path)
+        return f"<Process {self.path}>"
 
     def spawnProcess(self, proto, program, path):
         """
@@ -660,7 +656,7 @@ class MultiWrapper:
         @rtype: L{bytes}
         @return: A string containing a list of the message receivers.
         """
-        return "<GroupWrapper {!r}>".format(map(str, self.objs))
+        return f"<GroupWrapper {map(str, self.objs)!r}>"
 
 
 @implementer(IAlias)
@@ -701,7 +697,7 @@ class AliasGroup(AliasBase):
                 try:
                     f = open(addr[1:])
                 except BaseException:
-                    log.err("Invalid filename in alias file {!r}".format(addr[1:]))
+                    log.err(f"Invalid filename in alias file {addr[1:]!r}")
                 else:
                     with f:
                         addr = " ".join([l.strip() for l in f])
