@@ -78,7 +78,7 @@ See also L{incremental.Version}.
 @var DEPRECATION_WARNING_FORMAT: The default deprecation warning string format
     to use when one is not provided by the user.
 """
-
+from __future__ import annotations
 
 __all__ = [
     "deprecated",
@@ -100,6 +100,10 @@ from typing import Any, Callable, Dict, Optional, TypeVar, cast
 from warnings import warn, warn_explicit
 
 from incremental import Version, getVersionString
+from typing_extensions import ParamSpec
+
+_P = ParamSpec("_P")
+_R = TypeVar("_R")
 
 DEPRECATION_WARNING_FORMAT = "%(fqpn)s was deprecated in %(version)s"
 
@@ -259,7 +263,9 @@ def _appendToDocstring(thingWithDoc, textToAppend):
     thingWithDoc.__doc__ = "\n".join(docstringLines)
 
 
-def deprecated(version, replacement=None):
+def deprecated(
+    version: Version, replacement: str | Callable[..., object] | None = None
+) -> Callable[[Callable[_P, _R]], Callable[_P, _R]]:
     """
     Return a decorator that marks callables as deprecated. To deprecate a
     property, see L{deprecatedProperty}.
@@ -276,7 +282,7 @@ def deprecated(version, replacement=None):
     @type replacement: C{str} or callable
     """
 
-    def deprecationDecorator(function):
+    def deprecationDecorator(function: Callable[_P, _R]) -> Callable[_P, _R]:
         """
         Decorator that marks C{function} as deprecated.
         """
@@ -285,7 +291,7 @@ def deprecated(version, replacement=None):
         )
 
         @wraps(function)
-        def deprecatedFunction(*args, **kwargs):
+        def deprecatedFunction(*args: _P.args, **kwargs: _P.kwargs) -> _R:
             warn(warningString, DeprecationWarning, stacklevel=2)
             return function(*args, **kwargs)
 
@@ -595,12 +601,19 @@ def warnAboutFunction(offender, warningString):
     """
     # inspect.getmodule() is attractive, but somewhat
     # broken in Python < 2.6.  See Python bug 4845.
+    # In Python 3.13 line numbers returned by findlinestarts
+    # can be None for bytecode that does not map to source
+    # lines.
     offenderModule = sys.modules[offender.__module__]
     warn_explicit(
         warningString,
         category=DeprecationWarning,
         filename=inspect.getabsfile(offenderModule),
-        lineno=max(lineNumber for _, lineNumber in findlinestarts(offender.__code__)),
+        lineno=max(
+            lineNumber
+            for _, lineNumber in findlinestarts(offender.__code__)
+            if lineNumber is not None
+        ),
         module=offenderModule.__name__,
         registry=offender.__globals__.setdefault("__warningregistry__", {}),
         module_globals=None,
@@ -671,7 +684,7 @@ def _passedSignature(signature, positional, keyword):
     result = {}
     kwargs = None
     numPositional = 0
-    for (n, (name, param)) in enumerate(signature.parameters.items()):
+    for n, (name, param) in enumerate(signature.parameters.items()):
         if param.kind == inspect.Parameter.VAR_POSITIONAL:
             # Varargs, for example: *args
             result[name] = positional[n:]
